{% extends 'base.html.twig' %}

{% block title %}Hello OrderController!{% endblock %}

{% block body %}
  <div id="addressModal" class="hidden fixed items-center left-0 top-0 z-1 px-8 w-full h-full bg-opacity-60 bg-black">
    <div class="mt-32 flex flex-col gap-4 container mx-auto max-w-2xl h-auto p-5 shadow-xl bg-white rounded-lg">
      <div class="flex justify-between">
        <span class="font-bold mb-2">افزودن آدرس پستی</span>
        <div id="closeIcon" class="flex justify-end hover:cursor-pointer">
          <svg class="w-4 h-4 sm:w-6 sm:h-6" xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="100" height="100" viewBox="0 0 30 30">
            <path d="M 7 4 C 6.744125 4 6.4879687 4.0974687 6.2929688 4.2929688 L 4.2929688 6.2929688 C 3.9019687 6.6839688 3.9019687 7.3170313 4.2929688 7.7070312 L 11.585938 15 L 4.2929688 22.292969 C 3.9019687 22.683969 3.9019687 23.317031 4.2929688 23.707031 L 6.2929688 25.707031 C 6.6839688 26.098031 7.3170313 26.098031 7.7070312 25.707031 L 15 18.414062 L 22.292969 25.707031 C 22.682969 26.098031 23.317031 26.098031 23.707031 25.707031 L 25.707031 23.707031 C 26.098031 23.316031 26.098031 22.682969 25.707031 22.292969 L 18.414062 15 L 25.707031 7.7070312 C 26.098031 7.3170312 26.098031 6.6829688 25.707031 6.2929688 L 23.707031 4.2929688 C 23.316031 3.9019687 22.682969 3.9019687 22.292969 4.2929688 L 15 11.585938 L 7.7070312 4.2929688 C 7.5115312 4.0974687 7.255875 4 7 4 z"></path>
          </svg>
        </div>
      </div>
      <form action="{{ path("app_submit_address") }}" method="post" class="flex flex-col gap-4">
        <div class="sm:flex sm:flex-row flex flex-col gap-4">
          <div class="w-full flex flex-col gap-2">
            <label for="state">استان*</label>
            <select class="border border-gray-300 rounded-lg p-2 focus-within:outline-none" name="state" id="state">
              <option>استان را انتخاب کنید</option>
            {% for province in provinces %}
              <option value="{{ province.id }}">{{ province.name }}</option>
            {% endfor %}
            </select>
          </div>
          <div class="w-full flex flex-col gap-2">
            <label for="city">شهر*</label>
            <select class="border border-gray-300 rounded-lg p-2 focus-within:outline-none" name="city" id="city">
              <option>استان را انتخاب کنید</option>
            </select>
          </div>
        </div>
        <div class="flex flex-col gap-2">
          <label for="postcode">کد پستی*</label>
          <input required inputmode="numeric" name="postcode" id="postcode" class="w-full overflow-hidden rounded-lg border border-gray-300 p-2 focus-within:outline-none" >
        </div>
        <div class="flex flex-col gap-2">
          <label for="postcode">نشانی کامل پستی*</label>
          <textarea required name="address" id="address" class="resize-none w-full overflow-hidden rounded border border-gray-300 px-2.5 py-2 focus-within:outline-none" ></textarea>
        </div>
        <div class="flex justify-center">
            <button type="submit" class="w-full p-2 sm:p-3 text-xs sm:text-sm bg-black text-white border-2 border-transparent focus:outline-none hover:bg-gray-900 hover:opacity-65 hover:cursor-pointer transition duration-300 rounded-lg">
              تایید و ادامه
            </button>
        </div>
      </form>
    </div>
  </div>

  <form action="{{ path('app_new_order') }}" method="post">
    <div class="grid lg:grid-cols-3 grid-cols-2 justify-evenly container mx-auto gap-4 mt-10">
      <div class="col-span-2 flex flex-col gap-4">
        {# {% if not addresses %}
          {{ include('address/new.html.twig') }}
        {% endif %} #}

        {% for address in addresses %}
        <label class="flex flex-col bg-white cursor-pointer border border-gray-300 rounded-lg p-4">
          <div class="flex items-start gap-2">
          <div class="relative flex h-fit cursor-pointer items-center justify-center text-sm lg:text-base">
            <input class="peer/checkbox h-4 w-4 cursor-pointer appearance-none rounded-full border border-[#c54b4b] transition-all" type="radio" value="{{ address.id }}" checked name="address">
            <div class="absolute hidden h-2 w-2 rounded-full bg-[#d76363] peer-checked/checkbox:flex">
            </div>
          </div>
            <div class="flex flex-col gap-2">
              <span class="text-xs text-gray-500">آدرس دریافت سفارش</span>
              <span class="text-sm">{{ address.province }}</span>
              <span class="text-sm">{{ address.address }}</span>
            </div>
          </div>
          <div class="flex justify-end mt-4">
            <a href="{{ path('app_remove_address', {
              'id': address.id
            }) }}" class="text-red-500">حذف</a>
          </div>
        </label>
        {% endfor %}
        <a href="#" id="newAddress">
          <div class="flex justify-center items-center bg-white border border-gray-300 rounded-lg py-8">
            افزودن آدرس جدید +
          </div>
        </a>
        <div class="flex flex-col bg-white border border-gray-300 rounded-lg p-4">
          <span class="text-xs text-gray-500">شیوه زمان ارسال</span>
          <a href="#">
              <input class="float-left cursor-pointer py-2 px-6 bg-black mt-4 rounded-lg text-sm text-white outline-none" type="button" value="انتخاب زمان ارسال" >
          </a>
        </div>
      </div>
      <div class="lg:col-span-1 col-span-2 flex flex-col gap-2 items-center h-fit p-8 bg-white border border-gray-200 rounded-lg">
          <span class="text-xl font-bold mb-4">خلاصه صورتحساب</span>
          <div class="w-full flex justify-between">
              <span class="text-gray-500 text-sm">مبلغ کل</span>
              <span class="text-gray-500 text-sm">{{ numberConvertor(totalPrice) }} تومان</span>
          </div>
          <div class="w-full flex justify-between">
              <span class="text-gray-500 text-sm">هزینه ارسال</span>
              <span class="text-gray-500 text-sm">وابسته به آدرس</span>
          </div>
          <div class="lg:gap-20 gap-10 w-full flex justify-between">
              <span class="text-gray-500 text-sm">مبلغ قابل پرداخت</span>
              <span class="text-gray-500 text-sm">{{ numberConvertor(totalPrice) }} تومان</span>
          </div>
            <input type="submit" class="cursor-pointer py-2 px-6 border border-black mt-4 rounded-lg text-lg text-black  outline-none" type="button" value="تکمیل خرید" >
      </div>
    </div>
  </form>

  {% block javascripts %}
  <script>
    var newAddressBtn = document.getElementById('newAddress');
    var addressModal = document.getElementById('addressModal');
    var closeBtn = document.getElementById('closeIcon');

    newAddressBtn.addEventListener('click', function() {
      addressModal.classList.remove('hidden');
    })

    closeBtn.addEventListener('click', function() {
      addressModal.classList.add('hidden');
    })

    window.onclick = function(event) {
      if (event.target == addressModal) {
        addressModal.classList.add('hidden');
      }
  }
  </script>
  <script>
  $('#state').change(function () {
    var id = $(this).find('option:selected').val();
    $.ajax({
        method:'post',
        url: "{{ path('app_ajax') }}",
        data:{id:id},
        success:function(msg) {
          $('#city').empty();
          for (i = 0; i < msg.length; i++) {
            $('#city').append(new Option(msg[i].name, msg[i].value));
          }
        }
    })
  });
  </script>
  {% endblock %}

{% endblock %}
